@@ -1,5 +1,8 @@
 {-# LANGUAGE EmptyDataDecls #-}
-module OpenCascade.Font.Types where
+module OpenCascade.Font.Types 
+( BRepFont
+, BRepTextBuilder
+) where
 
 data BRepFont
 data BRepTextBuilder 
\ No newline at end of file
