@@ -1,5 +1,20 @@
 {-# LANGUAGE CApiFFI #-}
-module OpenCascade.GP.Internal.Destructors where
+module OpenCascade.GP.Internal.Destructors
+( deletePnt
+, deletePnt2d
+, deleteAx1
+, deleteAx2
+, deleteAx2d
+, deleteAx3
+, deleteDir
+, deleteDir2d
+, deleteVec
+, deleteVec2d
+, deleteTrsf
+, deleteTrsf2d
+, deleteGTrsf
+, deleteXYZ
+) where
 
 import OpenCascade.GP.Types
 
@@ -18,4 +33,5 @@ foreign import capi unsafe "hs_gp_Vec2d.h hs_delete_gp_Vec2d" deleteVec2d :: Ptr
 foreign import capi unsafe "hs_gp_Trsf.h hs_delete_gp_Trsf" deleteTrsf :: Ptr Trsf -> IO ()
 foreign import capi unsafe "hs_gp_GTrsf.h hs_delete_gp_GTrsf" deleteGTrsf :: Ptr GTrsf -> IO ()
 foreign import capi unsafe "hs_gp_Trsf2d.h hs_delete_gp_Trsf2d" deleteTrsf2d :: Ptr Trsf2d -> IO ()
+foreign import capi unsafe "hs_gp_XYZ.h hs_delete_gp_XYZ" deleteXYZ :: Ptr XYZ -> IO ()
 
