@@ -4,6 +4,7 @@ module OpenCascade.Geom.Types
 ( Curve
 , TrimmedCurve
 , BezierCurve
+, BSplineCurve
 , Surface
 ) where
 
@@ -12,7 +13,9 @@ import OpenCascade.Inheritance
 data Curve
 data TrimmedCurve
 data BezierCurve
+data BSplineCurve
 data Surface
 
 instance SubTypeOf Curve TrimmedCurve
 instance SubTypeOf Curve BezierCurve
+instance SubTypeOf Curve BSplineCurve
